package net.bjoerks.httpgetpostrequest_assertxmlreq_asynk;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.Reader;
import java.net.HttpURLConnection;
import java.net.URL;

import android.content.Context;
import android.widget.RemoteViews.ActionException;

/* Udarbejdet at Bjørk Boye Busch */
public class DataHelper {

    // Indlæser indhold fra fil i asset mappen ind i en String
    public static String readAssetFileIntoString(Context context, String assetFileName) throws Exception {
        InputStream inStream = context.getAssets().open(assetFileName);
        return DataHelper.InputStream2String(inStream);
    }

    // Indlæser indhold fra en InputStream ind i en String
    public static String InputStream2String(InputStream inStream) throws Exception   {
        char[] buffer = new char[1000];
        StringBuilder out = new StringBuilder();
        Reader in = new InputStreamReader(inStream, "UTF-8");
        int readCount;
        do {
            readCount = in.read(buffer, 0, buffer.length);
            if (readCount>0) {
                out.append(buffer, 0, readCount);
            }
        } while (readCount>=0);
        return out.toString();
    }

    // Sender POST request med postReqData til urlAdress og returner response som en String
    public static String getHttpPostRequest(String urlAdress, String contentType, String soapAction, String postReqData) throws Exception
    {
        URL url = new URL(urlAdress);
        HttpURLConnection httpCon = (HttpURLConnection) url.openConnection();
        httpCon.setUseCaches (false);
        httpCon.setDoInput(true);
        httpCon.setDoOutput(true);

        httpCon.setRequestMethod("POST");
        if (contentType!=null && contentType.length()>0)
            httpCon.setRequestProperty("Content-Type",contentType);

        if (soapAction != null && soapAction.length()>0)
            httpCon.setRequestProperty("SOAPAction",soapAction);

        httpCon.setRequestProperty("Content-Length",""+postReqData.length());

        OutputStream outStream = httpCon.getOutputStream();

        PrintWriter outTextStream = new PrintWriter(outStream);
        outTextStream.print(postReqData);								// ikke println, da linieskift skal med i length
        outTextStream.close();

        if (httpCon.getResponseCode()==HttpURLConnection.HTTP_OK){
            InputStream inStream = httpCon.getInputStream();

            // læser input ind i en String
            String response = DataHelper.InputStream2String(inStream);

            inStream.close();
            return response;
        }
        else{
            return "Error: returmsg=<"+httpCon.getResponseMessage()+">\n";
        }
    }

    // Sender GET request returner response som en String
    public static String getHttpGetRequest(String urlAdress, String contentType) throws Exception
    {
        URL url = new URL(urlAdress);
        HttpURLConnection httpCon = (HttpURLConnection) url.openConnection();
        httpCon.setUseCaches (false);
        httpCon.setDoInput(true);
        httpCon.setDoOutput(false);

        httpCon.setRequestMethod("GET");
        if (contentType!=null && contentType.length()>0)
            httpCon.setRequestProperty("Content-Type",contentType);


        if (httpCon.getResponseCode()==HttpURLConnection.HTTP_OK){
            InputStream inStream = httpCon.getInputStream();

            // læser input ind i en String
            String response = DataHelper.InputStream2String(inStream);

            inStream.close();
            return response;
        }
        else{
            return "Error: returmsg=<"+httpCon.getResponseMessage()+">\n";
        }
    }

}
